@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML;
 our $AUTHORITY = 'cpan:JANDREW';
-use version 0.77; our $VERSION = qv('v0.38.14');
+use version 0.77; our $VERSION = qv('v0.38.16');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML-$VERSION";
 
 use 5.010;
@@ -17,19 +17,20 @@ use Types::Standard qw(
  		InstanceOf			Str       		StrMatch
 		Enum				HashRef			ArrayRef
 		CodeRef				Int				HasMethods
-		Bool
+		Bool				is_Object		is_HashRef
     );
 use	MooseX::ShortCut::BuildInstance 1.032 qw( build_instance should_re_use_classes );
+should_re_use_classes( 1 );
 use lib	'../../../../lib',;
 #~ use Data::Dumper;
 ###LogSD with 'Log::Shiras::LogSpace';
 ###LogSD use Log::Shiras::Telephone;
 ###LogSD use Log::Shiras::UnhideDebug;
-should_re_use_classes( 1 );
 use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles;
 use	Spreadsheet::XLSX::Reader::LibXML::FmtDefault;
 use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings;
-use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet;
+use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::WorksheetToRow;
+use	Spreadsheet::XLSX::Reader::LibXML::Worksheet;
 use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Chartsheet;
 use	Spreadsheet::XLSX::Reader::LibXML::Error;
 use	Spreadsheet::XLSX::Reader::LibXML::Types qw( XLSXFile ParserType IOFileType );
@@ -41,18 +42,19 @@ my	$parser_modules ={
 			build_method => '_build_reader',
 			sharedStrings =>{
 				superclasses	=> ['Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings'],
-				attributes		=> [qw( error_inst cache_positions )],
+				attributes		=> [qw( error_inst cache_positions empty_return_type group_return_type )],
 				store			=> '_set_shared_strings_instance',
 				package			=> 'SharedStringsInstance',
 			},
 			styles =>{
 				superclasses	=> ['Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles'],
-				attributes		=> [qw( error_inst format_inst )],
+				attributes		=> [qw( error_inst cache_positions format_inst empty_return_type )],
 				store			=> '_set_styles_instance',
 				package			=> 'StylesInstance',
 			},
 			worksheet =>{
-				superclasses	=> ['Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet'],
+				superclasses	=> ['Spreadsheet::XLSX::Reader::LibXML::XMLReader::WorksheetToRow'],
+				roles			=> ['Spreadsheet::XLSX::Reader::LibXML::Worksheet'],
 				package			=> 'WorksheetInstance',
 			},
 			chartsheet =>{
@@ -83,8 +85,15 @@ my	$build_ref	= {
 		},
 	};
 my	$attribute_defaults ={
-		error_inst			=> Spreadsheet::XLSX::Reader::LibXML::Error->new( should_warn => 0 ),
-		format_inst			=> Spreadsheet::XLSX::Reader::LibXML::FmtDefault->new,
+		error_inst =>{
+			superclasses => ['Spreadsheet::XLSX::Reader::LibXML::Error'],
+			package => 'ErrorInstance',
+			should_warn => 0,
+		},
+		format_inst =>{
+			superclasses => ['Spreadsheet::XLSX::Reader::LibXML::FmtDefault'],
+			package => 'FormatInstance',
+		},
 		sheet_parser		=> 'reader',
 		count_from_zero		=> 1,
 		file_boundary_flags	=> 1,
@@ -107,12 +116,29 @@ my	$flag_settings ={
 			group_return_type => 'value',
 			cache_positions   => 1,
 			from_the_edge     => 0,
+			empty_return_type => 'undef_string',
+		},
+		just_raw_data =>{
+			count_from_zero   => 0,
+			values_only       => 1,
+			empty_is_end      => 1,
+			group_return_type => 'unformatted',
+			cache_positions   => 1,
+			from_the_edge     => 0,
+			empty_return_type => 'undef_string',
 		},
 		like_ParseExcel =>{
 			count_from_zero => 1,
 			cache_positions	=> 1,
 			group_return_type => 'instance',
 		},
+		debug =>{
+			error_inst =>{
+				superclasses => ['Spreadsheet::XLSX::Reader::LibXML::Error'],
+				package => 'ErrorInstance',
+				should_warn => 1,
+			},
+		},
 	};
 
 #########1 Public Attributes  3#########4#########5#########6#########7#########8#########9
@@ -129,7 +155,7 @@ has error_inst =>(
 			error set_error clear_error set_warnings if_warn
 		) ],
 		trigger => sub{
-			if( $_[0]->_has_formate_inst and !$_[0]->get_format_inst->block_inherit ){
+			if( $_[0]->_has_format_inst and !$_[0]->get_format_inst->block_inherit ){
 				$_[0]->get_format_inst->set_error_inst( $_[1] );
 			}
 		},
@@ -145,7 +171,7 @@ has format_inst =>(
 						parse_excel_format_string							)],	
 		writer	=> 'set_format_inst',
 		reader	=> 'get_format_inst',
-		predicate => '_has_formate_inst',
+		predicate => '_has_format_inst',
 		handles =>[qw(
 						get_defined_excel_format 	parse_excel_format_string
 						change_output_encoding		set_date_behavior
@@ -239,24 +265,31 @@ has cache_positions =>(
 	);
 
 #########1 Public Methods     3#########4#########5#########6#########7#########8#########9
-
+#~ use Data::Dumper;
 sub import{# Flags handled here!
     my ( $self, @flag_list ) = @_;
-	if( exists $ENV{SPREADSHEET_READ_XLSX} and 
-		$ENV{SPREADSHEET_READ_XLSX} == "Spreadsheet::XLSX::Reader::LibXML" ){
-		push @flag_list, ':like_ParseExcel';
-	}
+	
 	if( scalar( @flag_list ) ){
 		for my $flag ( @flag_list ){
 			#~ print "Arrived at import with flag: $flag\n";
-			if( $flag =~ /^:(\w*)$/ ){
+			if( $flag =~ /^:(\w*)$/ ){# Handle text based flags
 				my $default_choice = $1;
 				#~ print "Attempting to change the default group type to: $default_choice\n";
 				if( exists $flag_settings->{$default_choice} ){
-					map{ $attribute_defaults->{$_} = $flag_settings->{$default_choice}->{$_} } keys %{$flag_settings->{$default_choice}};
+					for my $attribute ( keys %{$flag_settings->{$default_choice}} ){
+						#~ print "Changing flag -$attribute- to:" . Dumper( $flag_settings->{$default_choice}->{$attribute} );
+						$attribute_defaults->{$attribute} = $flag_settings->{$default_choice}->{$attribute};
+					}
 				}else{
 					confess "No settings available for the flag: $flag";
 				}
+			}elsif( $flag =~ /^v?\d+\.?\d*/ ){# Version check may wind up here
+				#~ print "Running version check on version: $flag\n";
+				my $result = $VERSION <=> version->parse( $flag );
+				#~ print "Tested against version -$VERSION- gives result: $result\n";
+				if( $result < 0 ){
+					confess "Version -$flag- required - the installed version is: $VERSION";
+				}
 			}else{
 				confess "Passed attribute default flag -$flag- does not comply with the correct format";
 			}
@@ -267,8 +300,8 @@ sub import{# Flags handled here!
 sub parse{
 
     my ( $self, $file, $formatter ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::parse', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::parse', );
 	###LogSD		$phone->talk( level => 'info', message =>[
 	###LogSD			"Arrived at parse for:", $file,
 	###LogSD			(($formatter) ? "with formatter: $formatter" : '') ] );
@@ -293,8 +326,8 @@ sub parse{
 sub worksheets{
 
     my ( $self, ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::worksheets', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::worksheets', );
 	###LogSD		$phone->talk( level => 'info', message =>[
 	###LogSD			'Attempting to build all worksheets: ', $self->get_worksheet_names ] );
 	my	@worksheet_array;
@@ -312,8 +345,8 @@ sub worksheet{
 
     my ( $self, $worksheet_name ) = @_;
 	my ( $next_position );
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::worksheet', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::worksheet', );
 	###LogSD		$phone->talk( level => 'info', message =>[
 	###LogSD			"Arrived at (build a) worksheet with: ", $worksheet_name ] );
 	
@@ -379,12 +412,13 @@ sub worksheet{
 	
 	confess "No worksheet info for: $worksheet_name" if !exists $worksheet_info->{sheet_position};
 	$args{superclasses}			= $parser_type->{superclasses};
+	$args{roles}				= $parser_type->{roles};
 	$args{sheet_name}			= $worksheet_name;
 	$args{workbook_instance}	= $self;
 	$args{error_inst}			= $self->get_error_inst;
 	$args{package}				= $parser_type->{package};
-	###LogSD $args{log_space} = $self->get_log_space . "::Worksheet";# FUTURE COMMON DECISION
-	###LogSD	$phone->talk( level => 'debug', message =>[
+	###LogSD $args{log_space} = $self->get_log_space;
+	###LogSD	$phone->talk( level => 'trace', message =>[
 	###LogSD		'Finalized build info:', %args, ] );
 	my	$worksheet = build_instance( %args );
 	if( $worksheet ){
@@ -436,7 +470,7 @@ has _epoch_year =>(
 		predicate	=> 'has_epoch_year',
 		default		=> 1900,
 		trigger => sub{
-			if( $_[0]->_has_formate_inst and !$_[0]->get_format_inst->block_inherit ){
+			if( $_[0]->_has_format_inst and !$_[0]->get_format_inst->block_inherit ){
 				$_[0]->get_format_inst->set_epoch_year( $_[1] );
 			}
 		},
@@ -467,15 +501,15 @@ has _styles_instance =>(
 	);
 
 has _calc_chain_instance =>(
-	isa	=> 	HasMethods[qw( get_calc_chain_position )],
-	writer	=>'_set_calc_chain_instance',
-	reader	=>'_get_calc_chain_instance',
-	clearer	=> '_clear_calc_chain',
-	predicate => '_has_calc_chain_file',
-	handles =>{
-		_demolish_calc_chain => 'DEMOLISH',
-	},
-);
+		isa	=> 	HasMethods[qw( get_calc_chain_position )],
+		writer	=>'_set_calc_chain_instance',
+		reader	=>'_get_calc_chain_instance',
+		clearer	=> '_clear_calc_chain',
+		predicate => '_has_calc_chain_file',
+		handles =>{
+			_demolish_calc_chain => 'DEMOLISH',
+		},
+	);
 
 has _worksheet_list =>(
 		isa		=> ArrayRef,
@@ -549,35 +583,85 @@ has _zip_file_handle =>(
 		writer	=> '_set_zip_file_handle',
 		reader	=> '_get_zip_file_handle',
 	);
+	
+###LogSD	has '+class_space' =>( default => 'Workbook' );
 
 #########1 Private Methods    3#########4#########5#########6#########7#########8#########9
 
 around BUILDARGS => sub {
     my ( $orig, $class, %args ) = @_;
+	###LogSD	my $log_space = $args{log_space};
+	###LogSD	$log_space .= '::' if $log_space;
+	###LogSD	$log_space .= 'Workbook::BUILDARGS';
 	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> 'Workbook::BUILDARGS', );
+	###LogSD					name_space 	=> $log_space, );
 	###LogSD		$phone->talk( level => 'trace', message =>[
 	###LogSD			'Arrived at BUILDARGS with: ', %args ] );
+	
+	# Check if this was called by Spreadsheet::Read;
+	my $like_ParseExcel = 0;
+	for my $x ( 2 .. 5 ){
+		###LogSD	$phone->talk( level => 'trace', message =>[
+		###LogSD		"Caller is:", caller( $x ) ] );
+		if( (caller( $x ))[0] and (caller( $x ))[0] =~ /Spreadsheet::Read/ ){
+			$like_ParseExcel = 1;
+			###LogSD	$phone->talk( level => 'trace', message =>[
+			###LogSD		"Spreadsheet::XLSX::Reader::LibXML is being called by Spreadsheet::Read - enforcing the :like_ParseExcel flag" ] );
+			last;
+		}
+	}
+		
+	# Add any defaults
 	for my $key ( keys %$attribute_defaults ){
 		if( exists $args{$key} ){
 			###LogSD	$phone->talk( level => 'trace', message =>[
-			###LogSD			"Found user defined -$key- with value: $args{$key}" ] );
+			###LogSD		"Found user defined -$key- with value: $args{$key}" ] );
 		}else{
 			###LogSD	$phone->talk( level => 'trace', message =>[
-			###LogSD			"Setting default -$key- with value: $attribute_defaults->{$key}" ] );
-			$args{$key} = $attribute_defaults->{$key};
+			###LogSD		"Setting default -$key- with value: $attribute_defaults->{$key}" ] );
+			$args{$key} = clone( $attribute_defaults->{$key} );
 		}
 	}
+	
+	# Enforce Spreadsheet::Read requirements
+	if( $like_ParseExcel ){
+		###LogSD	$phone->talk( level => 'trace', message =>[
+		###LogSD		"Enforcing like_ParseExcel defaults" ] );
+		for my $key ( %{$flag_settings->{like_ParseExcel}} ){
+			$args{$key} = clone( $flag_settings->{like_ParseExcel}->{$key} );
+		}
+	}
+	
+	# Build object instances as needed
+	for my $key ( keys %args ){
+		###LogSD	$phone->talk( level => 'trace', message =>[
+		###LogSD		"Checking if an instance needs built for key: $key" ] );
+		if( $key =~ /_inst$/ and !is_Object( $args{$key} ) and is_HashRef( $args{$key} ) ){
+			# Import log_space as needed
+			###LogSD	if( exists $args{log_space} and $args{log_space} ){
+			###LogSD		$args{$key}->{log_space} = $args{log_space};
+			###LogSD	}
+			###LogSD	$phone->talk( level => 'trace', message =>[
+			###LogSD		"Key -$key- requires and instance built from:", $args{$key} ] );
+			$args{$key} = build_instance( $args{$key} );
+		}
+	}
+	
 	###LogSD	$phone->talk( level => 'trace', message =>[
 	###LogSD			"Final BUILDARGS:", %args ] );
     return $class->$orig(%args);
 };
 
+###LogSD	sub BUILD {
+###LogSD	    my $self = shift;
+###LogSD			$self->set_class_space( 'Workbook' );
+###LogSD	}
+
 sub _build_workbook{
 
     my ( $self, $file ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_build_file', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_build_file', );
 	###LogSD		$phone->talk( level => 'info', message =>[
 	###LogSD			'Arrived at _build_file for: ', $file ] );
 	$self->_clear_shared_strings;
@@ -665,8 +749,8 @@ sub _build_workbook{
 sub _build_dom{
 	my( $self, $target, $workbook_file ) = @_;
 	my $build_target = clone( $target );
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_build_dom', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_build_dom', );
 	###LogSD		$phone->talk( level => 'debug', message => [
 	###LogSD			'Building DOM object for the target:', $build_target,
 	###LogSD			"With file:", $workbook_file	] );
@@ -693,8 +777,8 @@ sub _build_dom{
 sub _build_reader{
 	my( $self, $target, $workbook_file ) = @_;
 	my $build_target = clone( $target );
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_build_reader', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_build_reader', );
 	###LogSD		$phone->talk( level => 'debug', message => [
 	###LogSD			'Building Reader object for the target:', $build_target,
 	###LogSD			"With file:", $workbook_file	] );
@@ -724,14 +808,16 @@ sub _build_reader{
 
 sub _load_top_level_workbook{
 	my( $self, $dom ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_load_workbook_file', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_load_workbook_file', );
 	###LogSD		$phone->talk( level => 'info', message => [
 	###LogSD			"Building the top level data for the workbook", ] );
 	my ( $list, $sheet_ref, $rel_lookup, $id_lookup );
 	my	$position = 0;
 	my ( $setting_node ) = $dom->getElementsByTagName( 'workbookPr' );
-	$self->_set_epoch_year( 1904 ) if $setting_node->getAttribute( 'date1904' );
+	if( $setting_node and $setting_node->getAttribute( 'date1904' ) ){
+		$self->_set_epoch_year( 1904 );
+	}
 	for my $sheet ( $dom->getElementsByTagName( 'sheet' ) ){
 		my	$sheet_name = $sheet->getAttribute( 'name' );
 		push @$list, $sheet_name;
@@ -770,8 +856,8 @@ sub _load_top_level_workbook{
 sub _load_workbook_rels{
 	my( $self, $rel_lookup, $dom ) = @_;
 	my ( $pivot_lookup, );
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_load_workbook_rels', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_load_workbook_rels', );
 	###LogSD		$phone->talk( level => 'debug', message => [
 	###LogSD			"Adding the rels file data for the workbook with:", $rel_lookup ] );
 	my	$sheet_ref = $self->_get_sheet_lookup;
@@ -819,8 +905,8 @@ sub _load_workbook_rels{
 
 sub _load_doc_props{
 	my( $self, $dom ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_load_doc_props', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_load_doc_props', );
 	###LogSD		$phone->talk( level => 'debug', message => [
 	###LogSD			"Collecting data from the doc props file", ] );
 	$self->_set_creator( ($dom->getElementsByTagName( 'dc:creator' ))[0]->textContent() );
@@ -836,8 +922,8 @@ sub _load_doc_props{
 
 sub _set_shared_worksheet_files{
 	my( $self, $object_ref, $zip_workbook ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_set_shared_worksheet_files', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_set_shared_worksheet_files', );
 	###LogSD	$phone->talk( level => 'debug', message => [
 	###LogSD		"Building the shared worksheet files with the lookup ref:", $object_ref, ] );
 	my $translation_method = $object_ref->{build_method};
@@ -876,12 +962,12 @@ sub _set_shared_worksheet_files{
 				push @$role_ref, $self->$method;
 			}
 			$args{add_roles_in_sequence} = $role_ref if $role_ref;
-			###LogSD	$args{log_space} = $self->get_log_space . "::$args{package}";
+			###LogSD	$args{log_space} = $self->get_log_space;
 			my $method = $object_ref->{$file}->{store};
 			###LogSD	$phone->talk( level => 'debug', message =>[
 			###LogSD		"Final args for building the instance:", %args,
 			###LogSD		"Loading -$method- with build_instance( 'args' )"	], );
-			my $object = build_instance( %args );
+			my $object = build_instance( %args );################################  Add a $object build-fail flag
 			###LogSD	$phone->talk( level => 'debug', message =>[
 			###LogSD		"Finished building instance for: $file",
 			###LogSD		"Loading to the worbook with method: $method", # $object	
@@ -899,8 +985,8 @@ sub _set_shared_worksheet_files{
 sub _import_format_settings{
 
     my ( $self, $formatter ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::_import_format_settings', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::_import_format_settings', );
 	if( !$formatter->block_inherit ){
 		###LogSD	$phone->talk( level => 'info', message =>[
 		###LogSD		'Arrived at _import_format_settings for: ', $formatter ] );
@@ -922,8 +1008,8 @@ sub _import_format_settings{
 
 sub DEMOLISH{
 	my ( $self ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> $self->get_log_space .  '::Workbook::DEMOLISH', );
+	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
+	###LogSD			$self->get_all_space . '::hidden::DEMOLISH', );
 	if( $self->_has_calc_chain_file ){
 		#~ print "closing calcChain.xml\n";
 		###LogSD	$phone->talk( level => 'debug', message => [
@@ -993,7 +1079,7 @@ Spreadsheet::XLSX::Reader::LibXML - Read xlsx spreadsheet files with LibXML
 </a>
 
 <a>
-	<img src="https://img.shields.io/badge/this version-0.38.14-brightgreen.svg" alt="this version">
+	<img src="https://img.shields.io/badge/this version-0.38.16-brightgreen.svg" alt="this version">
 </a>
 
 <a href="https://metacpan.org/pod/Spreadsheet::XLSX::Reader::LibXML">
@@ -1178,6 +1264,14 @@ L<Spreadsheet::XLSX::Reader::LibXML::FmtDefault/set_defined_excel_formats( %args
 attribute L<Spreadsheet::XLSX::Reader::LibXML::FmtDefault/defined_excel_translations>.    B<This warning 
 will be removed on 2/1/2016.>
 
+B<5.> This package now supports reading xlsm files (Macro enabled Excel 2007+ workbooks).  
+xlsm files allow for binaries to be embedded that may contain malicious code.  However, other 
+than unzipping the excel file no work is done by this package with the sub-file 'vbaProject.bin' 
+containing the binaries.  This update does not provide an API to that sub-file and I have no 
+intention of doing so.  Therefore my research indicates there should be no risk of virus activation 
+while parsing even an infected xlsm file with this package but I encourage you to use your own 
+judgement in this area.
+
 =head2 Attributes
 
 Data passed to new when creating an instance.  For modification of these attributes see the 
@@ -1198,13 +1292,13 @@ before the rest of the package can be used.>
 
 =over
 
-B<Definition:> This attribute holds the full file name and path for the xlsx file to be 
+B<Definition:> This attribute holds the full file name and path for the xlsx|xlsm file to be 
 parsed.
 
 B<Default> no default - either this or a L<file handle|/file_handle> must be provided to 
 read a file
 
-B<Range> any unencrypted xlsx file that can be opened in Microsoft Excel
+B<Range> any unencrypted xlsx|xlsm file that can be opened in Microsoft Excel.
 
 B<attribute methods> Methods provided to adjust this attribute
 		
@@ -2164,12 +2258,13 @@ Therefore you may want a shortcut that aggregates some set of attribute settings
 are not the defaults but wind up being boilerplate.  I have provided possible 
 alternate sets like this and am open to providing others that are suggested.  The 
 flags will have a : in front of the identifier and will be passed to the class in the 
-'use' statement for consumption by the import method.  Only the first flag is currently 
-accepted.
+'use' statement for consumption by the import method.  The flags can be stacked and 
+where there is conflict between the flag settings the rightmost passed flag setting is 
+used.
 
 Example;
 
-	use Spreadsheet::XLSX::Reader::LibXML v0.34.4 qw( :alt_default );
+	use Spreadsheet::XLSX::Reader::LibXML v0.34.4 qw( :alt_default :debug );
 
 =head2 :alt_default
 
@@ -2217,12 +2312,58 @@ L<from_the_edge|/from_the_edge> => 0,
 
 =back
 
+=head2 :just_raw_data
+
+This is intended for a shallow look at raw text and skips all formatting including number formats.
+
+=over
+
+B<Default attribute differences>
+
+=over
+
+L<values_only|/values_only> => 1
+
+L<count_from_zero|/count_from_zero> => 0
+
+L<empty_is_end|/empty_is_end> => 1
+
+L<group_return_type|/group_return_type> => 'unformatted'
+
+L<cache_positions|/cache_positions> => 1
+
+L<from_the_edge|/from_the_edge> => 0,
+
+=back
+
+=back
+
+=head2 :debug
+
+Turn on L<Spreadsheet::XLSX::Reader::LibXML::Error/should_warn> in the Error attribute (instance)
+
+=over
+
+B<Default attribute differences>
+
+=over
+
+L<Spreadsheet::XLSX::Reader::LibXML::Error/should_warn> => 1
+
+=back
+
+=back
+
 =head1 BUILD / INSTALL from Source
 
 B<0.> Please note that using L<cpanm|https://metacpan.org/pod/App::cpanminus> is much easier 
 than a source build! (but it will not always give the latest github version)
 
-	cpanm Spreadsheet-XLSX-Reader-LibXML
+	cpanm Spreadsheet::XLSX::Reader::LibXML
+	
+And then if you feel kindly
+
+	cpanm-reporter
 
 B<1.> This package uses L<Alien::LibXML> to try and ensure that the mandatory prerequisite 
 L<XML::LibXML> will load.  The biggest gotcha here is that older (<5.20.0.2) versions of 
@@ -2362,6 +2503,8 @@ L<Bill Baker|https://github.com/wdbaker54>
 
 L<H.Merijin Brand|https://github.com/Tux>
 
+L<Todd Eigenschink|mailto:todd@xymmetrix.com>
+
 =back
 
 =head1 COPYRIGHT
